#
# spec file for package xtables-addons
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           xtables-addons
Version:        1.37
Release:        0.3.1
Group:          Productivity/Networking/Security
Summary:        IP Packet Filter Administration Extensions
License:        GPL
Url:            http://xtables-addons.sf.net/
Source:         %name-%version.tar.xz
Source2:        %name-%version.tar.xz.asc
Source3:        %name-preamble
#Git-Clone:	git://xtables-addons.git.sf.net/gitroot/xtables-addons/xtables-addons
#Git-Web:	http://xtables-addons.git.sf.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %kernel_module_package_buildreqs
BuildRequires:  iptables-devel >= 1.4.3 libmnl-devel >= 1
BuildRequires:  pkg-config >= 0.23 xz
Recommends:     %name-kmp
# Yes, we've got a lot of good stuff!
%if 0%{?suse_version} >= 1140
Provides:       ipset = 6.7
%else
Provides:       ipset = 4.5
%endif
Recommends:     xtables-geoip

%define xtlibdir %(pkg-config xtables --variable=xtlibdir)

%kernel_module_package -p %name-preamble

%description
Xtables is used to set up, maintain, and inspect the tables of IP
packet filter rules in the Linux kernel.

Xtables-addons is the successor to patch-o-matic(-ng). Likewise, it
contains extensions that were not, or are not yet, accepted in the
main kernel/iptables packages.

%package KMP
Group:          System/Kernel
License:        GPL
Summary:        IP Packet Filter Administration Extensions

%description KMP
Xtables is used to set up, maintain, and inspect the tables of IP
packet filter rules in the Linux kernel.

Xtables-addons is the successor to patch-o-matic(-ng). Likewise, it
contains extensions that were not, or are not yet, accepted in the
main kernel/iptables packages.

%prep
%setup -q

%build
if [ ! -e configure ]; then
	./autogen.sh;
fi;
%if 0%{?suse_version} >= 1140
# ipset6-genl needs >=2.6.35
echo "build_ipset4=" >>mconfig;
echo "build_ipset6=m" >>mconfig;
%endif
pushd ../;
for flavor in %flavors_to_build; do
	cp -a "%name-%version" "%name-$flavor-%version";
	pushd "%name-$flavor-%version/";
	%configure --with-kbuild="/usr/src/linux-obj/%_target_cpu/$flavor";
	make %{?_smp_mflags};
	popd;
done;

%install
b="%buildroot";
#rm -Rf "$b";
#mkdir "$b";
pushd ../;
for flavor in %flavors_to_build; do
	pushd "%name-$flavor-%version/";
	make install DESTDIR="$b";
	popd;
done;
# There is no -devel package. So no need for these files.
find "$b/%_prefix" -iname "*.la" -delete;
find "$b/%_libdir" -maxdepth 1 -type l -iname "*.so" -delete;

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %_mandir/*/*
%_sbindir/*
%_libdir/*.so.*
%xtlibdir
%_libexecdir/xtables-addons

%changelog
* Sat Jun 25 2011 jengelh@medozas.de
- update to new upstream release 1.37
  * xt_SYSRQ: make IPv6 trigger work again
  * xt_SYSRQ: improve security: include host address in digest
  * xt_TARPIT: fix a kernel oops in --reset mode
* Fri Jun  3 2011 jengelh@medozas.de
- update to new upstream release 1.36
  * update to ipset 6.7
  * xt_TARPIT has gained the "honeypot" and "reset" modes
* Mon Apr 11 2011 jengelh@medozas.de
- Update to new upstream release 1.35
  * update to ipset 6.3
  * ipset-genl: handle EAGAIN return value emitted from autoloader
  * ipset-genl: resolve nfgenmsg remains and fix spurious protocol abort
* Thu Apr  7 2011 jengelh@medozas.de
- Update to new upstream release 1.34
  * xt_pknock: avoid crash when hash TFM could not be allocated
  * xt_pknock: avoid inversion of rule lookup that led to warnings
  * xt_DNETMAP: add missing module alias
  * xt_DNETMAP: support for kernels below 2.6.34
- Add kmp preamble file
* Wed Feb  2 2011 jengelh@medozas.de
- Update to new upstream release 1.33
  * IPv6 GeoIP support
  * New DNETMAP extension
  * Update to ipset 5.4-genl
* Fri Nov  5 2010 jengelh@medozas.de
- Update to new upstream release 1.31
  * LOGMARK: print remaining lifetime of ct entries
  * xt_iface: allow matching against incoming/outgoing interface
  * libxt_gradm: match packets based on status of grsecurity RBAC
* Sat Oct  9 2010 jengelh@medozas.de
- Do not build xt_TEE, xt_CHECKSUM; they are provided in newer
  iptables and kernel versions already
* Sun Oct  3 2010 jengelh@medozas.de
- new upstream release 1.30
  * support for Linux 2.6.36
  * update to ipset 4.4
  - ipport{,ip,net}hash did not work with mixed "src" and "dst"
    destination parameters
  * do ship ip_set_ipport{ip,net}hash
* Sat Jul 24 2010 jengelh@medozas.de
- new upstream release 1.28
  * RAWNAT: IPv6 variants erroneously rejected masks /33-/128
  * new target xt_CHECKSUM
  * xt_length2: add support for IPv6 jumbograms
  * xt_geoip: fix possible out-of-bounds access
  * import xt_geoip database scripts
* Tue Jun 29 2010 lnussel@suse.de
- don't require kernel module package (bnc#618244)
* Mon May 17 2010 jengelh@medozas.de
- new upstream release 1.27
  * support for upcoming Linux 2.6.35
* Sat May  1 2010 jengelh@medozas.de
- new upstream release 1.26
  * fix compile error with kernel 2.6.34
* Mon Apr 26 2010 jengelh@medozas.de
- new upstream release 1.25
  * incorporated changes from upstream review into xt_TEE:
    (rechecksumming in PREROUTING, decrease TTL on cloned packet, set
    dont-fragment on cloned packets, free skb when route lookup
    failed, do not limit use to mangle table, do not retain iif and
    mark on cloned packet, new loop detection logic, use less
    expensive pskb_copy)
* Wed Mar 17 2010 jengelh@medozas.de
- new upstream release 1.24
  * ipp2p: updated bittorent command recognition
* Thu Feb 25 2010 jengelh@medozas.de
- new upstream release 1.23
  * ipset updated to 4.2
  * removal of obsoleted configure options;
    compile fixes for IPV6=n and 2.6.32's skb_dst
  * support for Linux 2.6.33 and the projected 2.6.34 net tree
* Thu Feb 11 2010 ro@suse.de
- add KMP to specfile (to give description to kmp subpacks)
* Sat Jan 23 2010 jengelh@medozas.de
- new upstream release 1.22
  * ipset: enable build of ip_set_setlist.ko
  * quota2: add the --no-change mode
- remove merged patch geoip-dir.diff (use
  /usr/share/xt_geoip instead of /var/geoip)
* Thu Dec 31 2009 jengelh@medozas.de
- initial OBS package
* Wed Dec  9 2009 jengelh@medozas.de
- new upstream release: 1.21
  * fix clashing setsockopt numbers between xt_ACCOUNT and arptables
* Thu Nov 19 2009 jengelh@medozas.de
- new upstream release: 1.20
* Mon Oct 12 2009 jengelh@medozas.de
- new upstream release: 1.19
